@@ -5,14 +5,13 @@
 //! Ockam library.
 //!
 //! The main Ockam crate re-exports types defined in this crate.
-#![deny(
+#![deny(unsafe_code)]
+#![warn(
     missing_docs,
     trivial_casts,
     trivial_numeric_casts,
-    unsafe_code,
     unused_import_braces,
-    unused_qualifications,
-    warnings
+    unused_qualifications
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
@@ -105,13 +104,13 @@ mod tests {
 
             assert_eq!(initiator.h(), responder.h());
 
-            let s1 = vault.secret_export(&initiator.encrypt_key()).await.unwrap();
-            let s2 = vault.secret_export(&responder.decrypt_key()).await.unwrap();
+            let s1 = vault.secret_export(initiator.encrypt_key()).await.unwrap();
+            let s2 = vault.secret_export(responder.decrypt_key()).await.unwrap();
 
             assert_eq!(s1, s2);
 
-            let s1 = vault.secret_export(&initiator.decrypt_key()).await.unwrap();
-            let s2 = vault.secret_export(&responder.encrypt_key()).await.unwrap();
+            let s1 = vault.secret_export(initiator.decrypt_key()).await.unwrap();
+            let s2 = vault.secret_export(responder.encrypt_key()).await.unwrap();
 
             assert_eq!(s1, s2);
 
